#!/bin/sh

GPIB_ADAPTER_AGILENT="agilent_82357a"
GPIB_ADAPTER_NI_USB="ni_usb_b"

GPIB_MODPROBE_AGILENT="agilent_82357a"
GPIB_MODPROBE_NI_USB="ni_usb_gpib"

# Location of firmware for Agilent USB GPIB adapters
GPIB_FW="http://linux-gpib.sourceforge.net/firmware/gpib_firmware-2008-08-10.tar.gz"
GPIB_FW_HOME="gpib_firmware-2008-08-10/agilent_82357a/"


GPIB_HOME="/home/linux-gpib/"
GPIB_MAKE="linux-gpib-code/linux-gpib"

CONFIG_TXT="/boot/config.txt"
MODULES_FILE="/etc/modules"

MODULES1="i2c-bcm2708"
MODULES2="i2c-dev"
MODULES3="agilent_82357a"

OPT_HW1="dtparam=i2c_arm=on"
OPT_HW2="dtparam=i2c1=on"
OPT_HW3="dtparam=i2c0=on"
OPT_HW4="dtparam=spi=on"

OLD_GPIB_CONF_LINE="ni_pci"

find_string()
{
	if grep -x --silent $1 $2
	then return
	else echo "$1" >> "$2"
	fi
}

change_line()
{
	local OLD_LINE=$1
	local NEW_LINE=$2
	local FILE=$3

	sed -i "s/${OLD_LINE}/${NEW_LINE}/g" "$FILE"
	#echo "$OLD_LINE" "replaced with" "$NEW_LINE"
}

# Enable quiet mode = -qq . Use empty quote for verbose mode.
Q=" -qq "
#echo "Running dist-upgrade"
#apt-get $Q -y dist-upgrade
apt-get install $Q -y aptitude
apt-get install $Q -y nano
apt-get install $Q -y sudo
apt-get install $Q -y mercurial
apt-get install $Q -y python-smbus
apt-get install $Q -y python-dev
apt-get install $Q -y i2c-tools
apt-get install $Q -y gcc
apt-get install $Q -y make
apt-get install $Q -y automake
apt-get install $Q -y autoconf
apt-get install $Q -y subversion
apt-get install $Q -y libtool
apt-get install $Q -y flex
apt-get install $Q -y bison
apt-get install $Q -y usbutils

apt-get install $Q -y build-essential
apt-get install $Q -y texinfo
apt-get install $Q -y texi2html
apt-get install $Q -y libcwidget-dev
apt-get install $Q -y tcl8.4-dev
apt-get install $Q -y tk8.4-dev
apt-get install $Q -y libncurses5-dev
apt-get install $Q -y libx11-dev
apt-get install $Q -y binutils-dev
apt-get install $Q -y libusb-1.0.0
apt-get install $Q -y libusb-dev
apt-get install $Q -y libmpfr-dev
apt-get install $Q -y libexpat1-dev
apt-get install $Q -y tofrodos

# Add entries for /etc/modules
# Check if they already exist, and add if they don’t
find_string "$MODULES1" "$MODULES_FILE"
find_string "$MODULES2" "$MODULES_FILE"

# Add entries for /boot/config.txt
# Check if they already exist, and add if they don’t
echo "" >> /boot/config.txt
find_string "# Enable optional hardware interfaces" "$CONFIG_TXT"
find_string "$OPT_HW1" "$CONFIG_TXT"
find_string "$OPT_HW2" "$CONFIG_TXT"
find_string "$OPT_HW3" "$CONFIG_TXT"
find_string "$OPT_HW4" "$CONFIG_TXT"

mkdir $GPIB_HOME
svn checkout svn://svn.code.sf.net/p/linux-gpib/code/trunk /home/linux-gpib/linux-gpib-code
cd "$GPIB_HOME"
cd "$GPIB_MAKE"
pwd
echo "Running linux-gpib bootstrap"
./bootstrap
echo "Running linux-gpib configure"
./configure
echo "Making linux-gpib"
make | tee /var/log/gpib-make-log.log

echo "Installing linux-gpib"
make install

apt-get install $Q -y fxload

while true; do
echo "Which adapter is being installed?"
echo "1. Agilent 82357A/B"
echo "2. National Instruments GPIB-USB-HS"
echo "Enter 1 or 2"
read ADAPTER

echo $ADAPTER "was selected."
read -p "Is this correct? " yn
	case $yn in
		[Yy]*  ) break;;
		[Nn]* ) echo "Try again";;
		* ) echo "Please answer yes or no";;
	esac
done

# Install correct driver and modify gpib.conf file with correct adapter
if [ $ADAPTER -eq 1 ]
then
	# Add Agilent entry in /etc/modules if it doesn’t exist
	find_string "$MODULES3" "$MODULES_FILE"
	echo "Downloading firmware for Agilent USB adapters"
	cd "$GPIB_HOME"
	wget $GPIB_FW
	echo "Unzipping firmware..."
	tar xvzf gpib_firmware-2008-08-10.tar.gz

	change_line "$OLD_GPIB_CONF_LINE" "$GPIB_ADAPTER_AGILENT" "/etc/gpib.conf"
	change_line "$GPIB_ADAPTER_NI_USB" "$GPIB_ADAPTER_AGILENT" "/etc/gpib.conf"
	echo "Copying Agilent firmware file to expected location for rules"
	cp /home/linux-gpib/gpib_firmware-2008-08-10/agilent_82357a/measat_releaseX1.8.hex /usr/share/usb/agilent_82357a/
	echo "Copying rule to mount 82357b adapter on boot"
	cp /boot/77-agilent-82357b-gpib.rules /etc/udev/rules.d/

else change_line "$OLD_GPIB_CONF_LINE" "$GPIB_ADAPTER_NI_USB" "/etc/gpib.conf"
     change_line "$GPIB_ADAPTER_AGILENT" "$GPIB_ADAPTER_NI_USB" "/etc/gpib.conf"
     change_line "$MODULES3" "" "$MODULES_FILE"
fi
echo "Running depmod -a"
depmod -a
echo "Running ldconfig"
ldconfig
echo "Running modprobe"
# Modprobe driver with correct adapter
if [ $ADAPTER -eq 1 ]
then modprobe $GPIB_MODPROBE_AGILENT
else modprobe $GPIB_MODPROBE_NI_USB
fi
echo "Running gpib_config"
gpib_config

read -p "Do you wish to change the time zone? " yn
	case $yn in
		[Yy]*  )
			dpkg-reconfigure tzdata
			break;;
		[Nn]* ) break;;
		* ) echo "Please answer yes or no";;
	esac

read -p "Do you wish to change the default keyboard? " yn
	case $yn in
		[Yy]*  )
			dpkg-reconfigure locales
			dpkg-reconfigure keyboard-configuration
			break;;
		[Nn]* ) break;;
		* ) echo "Please answer yes or no";;
	esac

